nvector._core.select_ellipsoid — nvector 0.7.5 documentation

# nvector._core.select_ellipsoid

`select_ellipsoid`(name)

  Returns semi-major axis (a), flattening (f) and name of ellipsoid

  Parameters
    namestring

      name of ellipsoid. Valid options are: 1) Airy 1858 2) Airy Modified 3) Australian National 4) Bessel 1841 5) Clarke 1880 6) Everest 1830 7) Everest Modified 8) Fisher 1960 9) Fisher 1968 10) Hough 1956 11) International (Hayford)/European Datum (ED50) 12) Krassovsky 1938 13) NWL-9D (WGS 66) 14) South American 1969 15) Soviet Geod. System 1985 16) WGS 72 17) Clarke 1866 (NAD27) 18) GRS80 / WGS84 (NAD83) 19) ETRS89

  Examples

      >>> import nvector as nv
      >>> nv.select_ellipsoid(name='wgs84')
      (6378137.0, 0.0033528106647474805, 'GRS80 / WGS84  (NAD83)')
      >>> nv.select_ellipsoid(name='GRS80')
      (6378137.0, 0.0033528106647474805, 'GRS80 / WGS84  (NAD83)')
      >>> nv.select_ellipsoid(name='NAD83')
      (6378137.0, 0.0033528106647474805, 'GRS80 / WGS84  (NAD83)')
      >>> nv.select_ellipsoid(name=18)
      (6378137.0, 0.0033528106647474805, 'GRS80 / WGS84  (NAD83)')